{% with urlarchivo='https://docs.google.com/gview?url='|add:URL_GENERAL|add:archivo.url|add:'&embedded=true' %}
    {% if archivo_is_image %}
        <a data-caption="{{ caption|default:'' }}" data-fancybox="image{{ groupName|default:'' }}" href="{{ archivo.url }}">
            <img src="{{ archivo.url }}" style="width: 50px;object-fit: contain;" class="shadow-sm p-1 mb-5 bg-secondary rounded border-primary">
        </a>
    {% elif archivo_extension == "pdf" %}
        <a data-fancybox data-type="iframe" data-caption="{{ caption|default:'' }}" href="{{ archivo.url }}">
            {{ icono }} {{ nombre_btn }}
        </a>
    {% else %}
        <a data-caption="{{ caption|default:'' }}"
           data-fancybox data-type="iframe" href="{{ urlarchivo }}">
            {{ icono }} {{ nombre_btn }}
        </a>
    {% endif %}
{% endwith %}