{% load static %}<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Default offline template</title>
    <link href="{% static '/css/django-pwa-app.css' %}" rel="stylesheet">
</head>
<body>
<h1>You are currently not connected to any networks.</h1>
</body>
</html>